package com.changhu.support.interceptor;

import com.changhu.common.annotation.CheckClientType;
import com.changhu.common.exception.MessageException;
import com.changhu.common.utils.UserUtil;
import com.changhu.enums.ClientType;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import org.jetbrains.annotations.NotNull;
import org.springframework.web.method.HandlerMethod;
import org.springframework.web.servlet.HandlerInterceptor;

/**
 * @author 20252
 * @createTime 2024/9/4 下午4:00
 * @desc ClientTypeInterceptor...
 */
public class ClientTypeInterceptor implements HandlerInterceptor {

    @Override
    public boolean preHandle(@NotNull HttpServletRequest request,
                             @NotNull HttpServletResponse response,
                             @NotNull Object handler) {
        if (handler instanceof HandlerMethod handlerMethod) {
            boolean b = false;
            ClientType ct = null;

            CheckClientType clazzJsonBody = handlerMethod.getBeanType().getAnnotation(CheckClientType.class);
            CheckClientType methodJsonBody = handlerMethod.getMethodAnnotation(CheckClientType.class);

            if (clazzJsonBody != null) {
                if (methodJsonBody == null) {
                    b = true;
                    ct = clazzJsonBody.clientType();
                } else if (methodJsonBody.value()) {
                    b = true;
                    ct = methodJsonBody.clientType();
                }
            } else {
                if (methodJsonBody != null && methodJsonBody.value()) {
                    b = true;
                    ct = methodJsonBody.clientType();
                }
            }

            if (b) {
                if (!ct.equals(UserUtil.getClientType())) {
                    throw new MessageException("客户端类型不对");
                }
            }
        }
        return true;
    }
}
